'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class BundleScriptTagPlugin {
  constructor(options) {
    this.opts = Object.assign({
      prefix: 'bundle',
      output: './build',
      publicPath: '//',
      content: function content(assetPath) {
        return ['var n = document.createElement(\'script\');', `n.src = '${assetPath}';`, 'document.body.appendChild(n);'].join('');
      }
    }, options || {});
    this.apply = this.apply.bind(this);
  }

  apply(compiler) {
    var _opts = this.opts,
        output = _opts.output,
        prefix = _opts.prefix,
        publicPath = _opts.publicPath,
        content = _opts.content;


    var appDir = _fs2.default.realpathSync(process.cwd());
    var outputDir = _path2.default.resolve(appDir, output);

    var bundleScript = function bundleScript(stats) {
      var _stats$toJson = stats.toJson(),
          assets = _stats$toJson.assets;

      var jsFiles = assets.filter(function (_ref) {
        var name = _ref.name;
        return name.match(/\.js$/);
      });

      jsFiles.forEach(function (asset) {
        var name = asset.name,
            chunkNames = asset.chunkNames;


        var partial = chunkNames.join('');
        var filename = `${prefix}-${partial}.js`;
        var outputFile = _path2.default.resolve(outputDir, filename);
        var assetPath = `${publicPath}/${name}`;
        var fileContents = content(assetPath);

        _fs2.default.writeFile(outputFile, fileContents, function (err) {
          if (err) {
            process.stdout.write(err);
          }
        });
      });
    };

    // Run
    if (compiler.hooks) {
      compiler.hooks.done.tap('BundleScriptTagPlugin', bundleScript);
    } else {
      compiler.plugin('after-emit', function (compilation) {
        return bundleScript(compilation.getStats());
      });
    }
  }
}

exports.default = BundleScriptTagPlugin;